#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_POSMIN_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_POSMIN_HPP_INCLUDED

#include <boost/simd/reduction/include/functions/posmin.hpp>

#endif
